| Title: | Converting articles from PDF to text and managing and extracting basic information including tables |
|---|---|
| Description: | Converting articles from PDF to text and managing and extracting basic information including tables |
| Authors: | Sebastian Kranz (Ulm University) |
| Maintainer: | Sebastian Kranz <[email protected]> |
| License: | GPL >= 3.0 |
| Version: | 0.1 |
| Built: | 2026-05-26 07:38:43 UTC |
| Source: | https://github.com/repboxr/repboxArt |